[![Documentation Status](https://readthedocs.org/projects/sphinx-peakrdl/badge/?version=latest)](http://sphinx-peakrdl.readthedocs.io)
[![build](https://github.com/SystemRDL/PeakRDL/workflows/build/badge.svg)](https://github.com/SystemRDL/sphinx-peakrdl/actions?query=workflow%3Abuild+branch%3Amain)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sphinx-peakrdl.svg)](https://pypi.org/project/sphinx-peakrdl)

# PeakRDL integration for Sphinx-Doc

See the [Sphinx-PeakRDL Documentation](http://sphinx-peakrdl.readthedocs.io) for more details.
